

class InvalidUUID(Exception):
    """Exception for invalid UUID."""
    pass


class InvalidEndpointProtocol(Exception):
    """Exception for invalid endpoint protocol."""
    pass


class InvalidSurrogateID(Exception):
    """Exception for invalid surrogate ID in message-type"""
    pass
